==> modoboa-imap-migration-1.1.2.tar.gz: modoboa-imap-migration-1.1.2/modoboa_imap_migration/management/commands/generate_offlineimap_config.py <==
"""A management command to create an offlineimap configuration file."""

from django.core.management.base import BaseCommand
from django.template.loader import render_to_string

from modoboa.admin.app_settings import load_admin_settings
from modoboa.parameters import tools as param_tools

from ...modo_extension import ImapMigration
from ...models import Migration


class Command(BaseCommand):
    """Command definition."""

    help = "Generate an offlineimap configuration file."

    def add_arguments(self, parser):
        """Add extra arguments to command line."""
        parser.add_argument(
            "--output", default="/tmp/offlineimap.conf",
            help="Path of the generated file")

    def handle(self, *args, **options):
        """Entry point."""
        load_admin_settings()
        ImapMigration().load()
        conf = dict(
            param_tools.get_global_parameters("modoboa_imap_migration"))
        context = {
            "imap_server_address": conf["server_address"],
            "imap_server_port": conf["server_port"],
            "imap_server_secured": conf["secured"],
            "imap_create_folders": conf["create_folders"],
            "imap_folder_filter_exclude": conf["folder_filter_exclude"],
            "imap_folder_filter_include": ', '.join("'{0}'".format(w) for w in conf["folder_filter_include"].split(",")),
            "migrations": Migration.objects.select_related("mailbox").all(),
        }
        with open(options["output"], "w") as fpo:
            content = render_to_string(
                "modoboa_imap_migration/offlineimap.conf", context)
            fpo.write(content)

==> modoboa-imap-migration-1.3.0.tar.gz: modoboa-imap-migration-1.3.0/modoboa_imap_migration/management/commands/generate_offlineimap_config.py <==
"""A management command to create an offlineimap configuration file."""

from django.core.management.base import BaseCommand
from django.template.loader import render_to_string

from modoboa.admin.app_settings import load_admin_settings
from modoboa.parameters import tools as param_tools

from ...modo_extension import ImapMigration
from ...models import Migration


class Command(BaseCommand):
    """Command definition."""

    help = "Generate an offlineimap configuration file."

    def add_arguments(self, parser):
        """Add extra arguments to command line."""
        parser.add_argument(
            "--output", default="/tmp/offlineimap.conf",
            help="Path of the generated file")

    def handle(self, *args, **options):
        """Entry point."""
        load_admin_settings()
        ImapMigration().load()
        conf = dict(
            param_tools.get_global_parameters("modoboa_imap_migration"))
        context = {
            "imap_create_folders": conf["create_folders"],
            "imap_folder_filter_exclude": conf["folder_filter_exclude"],
            "imap_folder_filter_include": ", ".join(
                "'{0}'".format(w)
                for w in conf["folder_filter_include"].split(",")),
            "migrations": Migration.objects.select_related(
                "provider", "mailbox__domain"),
        }
        with open(options["output"], "w") as fpo:
            content = render_to_string(
                "modoboa_imap_migration/offlineimap.conf", context)
            fpo.write(content)
